==> 4.1.0.zip: alfresco-content-app/projects/aca-shared/src/public-api.ts <==
/*!
 * Copyright © 2005-2023 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

export * from './lib/adf-extensions/extensions-data-loader.guard';
export * from './lib/components/page-layout/page-layout-content.component';
export * from './lib/components/page-layout/page-layout-error.component';
export * from './lib/components/page-layout/page-layout-header.component';
export * from './lib/components/page-layout/page-layout.component';
export * from './lib/components/page-layout/page-layout.module';
export * from './lib/components/locked-by/locked-by.component';
export * from './lib/components/generic-error/generic-error.component';
export * from './lib/components/tool-bar/shared-toolbar.module';
export * from './lib/components/tool-bar/toolbar-action/toolbar-action.component';
export * from './lib/components/tool-bar/toolbar-button/toolbar-button.component';
export * from './lib/components/tool-bar/toolbar-menu/toolbar-menu.component';
export * from './lib/components/tool-bar/toolbar-menu-item/toolbar-menu-item.component';
export * from './lib/components/info-drawer/info-drawer.component';
export * from './lib/components/document-base-page/document-base-page.component';
export * from './lib/components/document-base-page/document-base-page.service';
export * from './lib/components/open-in-app/open-in-app.component';
export * from './lib/components/open-in-app/open-in-app.module';

export * from './lib/directives/contextmenu/contextmenu.directive';
export * from './lib/directives/contextmenu/contextmenu.module';
export * from './lib/directives/pagination.directive';
export * from './lib/directives/shared.directives.module';

export * from './lib/models/types';
export * from './lib/models/viewer.rules';
export * from './lib/models/modal-configuration';

export * from './lib/routing/shared.guard';

export * from './lib/services/app.service';
export * from './lib/services/content-api.service';
export * from './lib/services/node-permission.service';
export * from './lib/services/app.extension.service';
export * from './lib/services/router.extension.service';
export * from './lib/services/app-hook.service';
export * from './lib/services/alfresco-office-extension.service';
export * from './lib/services/aca-file-auto-download.service';

export * from './lib/utils/node.utils';
export * from './lib/shared.module';
export * from './lib/testing/lib-testing-module';

==> 5.1.1.zip: alfresco-content-app/projects/aca-shared/src/public-api.ts <==
/*!
 * Copyright © 2005-2024 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */

export * from './lib/adf-extensions/extensions-data-loader.guard';
export * from './lib/components/page-layout/page-layout-content.component';
export * from './lib/components/page-layout/page-layout-error.component';
export * from './lib/components/page-layout/page-layout-header.component';
export * from './lib/components/page-layout/page-layout.component';
export * from './lib/components/page-layout/page-layout.module';
export * from './lib/components/locked-by/locked-by.component';
export * from './lib/components/generic-error/generic-error.component';
export * from './lib/components/toolbar/toolbar.component';
export * from './lib/components/toolbar/toolbar-action/toolbar-action.component';
export * from './lib/components/toolbar/toolbar-button/toolbar-button.component';
export * from './lib/components/toolbar/toolbar-menu/toolbar-menu.component';
export * from './lib/components/toolbar/toolbar-menu-item/toolbar-menu-item.component';
export * from './lib/components/info-drawer/info-drawer.component';
export * from './lib/components/document-base-page/document-base-page.component';
export * from './lib/components/document-base-page/document-base-page.service';
export * from './lib/components/open-in-app/open-in-app.component';
export * from './lib/constants';
export * from './lib/directives/contextmenu/contextmenu.directive';
export * from './lib/directives/pagination.directive';

export * from './lib/models/types';
export * from './lib/models/viewer.rules';

export * from './lib/routing/shared.guard';
export * from './lib/routing/plugin-enabled.guard';

export * from './lib/services/app.service';
export * from './lib/services/content-api.service';
export * from './lib/services/node-permission.service';
export * from './lib/services/app.extension.service';
export * from './lib/services/router.extension.service';
export * from './lib/services/app-hook.service';
export * from './lib/services/auto-download.service';
export * from './lib/services/app-settings.service';
export * from './lib/services/user-profile.service';

export * from './lib/utils/node.utils';
export * from './lib/testing/lib-testing-module';

export * from './lib/deprecated/shared.module';
export * from './lib/deprecated/shared-toolbar.module';
